# Base Docker images

This images include [Resolwe Runtime Utilities](
http://resolwe-runtime-utils.readthedocs.io).

The `fedora-36` image is based on [`docker.io/fedora:36`](
https://hub.docker.com/_/fedora/).
The `ubuntu-22.04` image is based on [`docker.io/ubuntu:22.04`](
https://hub.docker.com/_/ubuntu/).

The base images are used as bases for all the other
Resolwe toolkit Docker images.
